# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectIntegrationGithubArgs', 'ProjectIntegrationGithub']

@pulumi.input_type
class ProjectIntegrationGithubArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[_builtins.str],
                 repository_url: pulumi.Input[_builtins.str],
                 token: pulumi.Input[_builtins.str],
                 static_context: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a ProjectIntegrationGithub resource.
        :param pulumi.Input[_builtins.str] project: ID of the project you want to activate the integration on.
        :param pulumi.Input[_builtins.str] token: A GitHub personal access token with at least the `repo:status` scope.
        :param pulumi.Input[_builtins.bool] static_context: Append the instance name instead of the branch to the status. Must enable to set a GitLab status check as *required* in GitHub. See [Static / dynamic status check names] to learn more.
        """
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "repository_url", repository_url)
        pulumi.set(__self__, "token", token)
        if static_context is not None:
            pulumi.set(__self__, "static_context", static_context)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        ID of the project you want to activate the integration on.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="repositoryUrl")
    def repository_url(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "repository_url")

    @repository_url.setter
    def repository_url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "repository_url", value)

    @_builtins.property
    @pulumi.getter
    def token(self) -> pulumi.Input[_builtins.str]:
        """
        A GitHub personal access token with at least the `repo:status` scope.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "token", value)

    @_builtins.property
    @pulumi.getter(name="staticContext")
    def static_context(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Append the instance name instead of the branch to the status. Must enable to set a GitLab status check as *required* in GitHub. See [Static / dynamic status check names] to learn more.
        """
        return pulumi.get(self, "static_context")

    @static_context.setter
    def static_context(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "static_context", value)


@pulumi.input_type
class _ProjectIntegrationGithubState:
    def __init__(__self__, *,
                 active: Optional[pulumi.Input[_builtins.bool]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_url: Optional[pulumi.Input[_builtins.str]] = None,
                 static_context: Optional[pulumi.Input[_builtins.bool]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProjectIntegrationGithub resources.
        :param pulumi.Input[_builtins.bool] active: Whether the integration is active.
        :param pulumi.Input[_builtins.str] created_at: Creation time.
        :param pulumi.Input[_builtins.str] project: ID of the project you want to activate the integration on.
        :param pulumi.Input[_builtins.bool] static_context: Append the instance name instead of the branch to the status. Must enable to set a GitLab status check as *required* in GitHub. See [Static / dynamic status check names] to learn more.
        :param pulumi.Input[_builtins.str] title: The title of this resource.
        :param pulumi.Input[_builtins.str] token: A GitHub personal access token with at least the `repo:status` scope.
        :param pulumi.Input[_builtins.str] updated_at: Update time.
        """
        if active is not None:
            pulumi.set(__self__, "active", active)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if repository_url is not None:
            pulumi.set(__self__, "repository_url", repository_url)
        if static_context is not None:
            pulumi.set(__self__, "static_context", static_context)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if token is not None:
            pulumi.set(__self__, "token", token)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)

    @_builtins.property
    @pulumi.getter
    def active(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the integration is active.
        """
        return pulumi.get(self, "active")

    @active.setter
    def active(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "active", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Creation time.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        ID of the project you want to activate the integration on.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="repositoryUrl")
    def repository_url(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "repository_url")

    @repository_url.setter
    def repository_url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repository_url", value)

    @_builtins.property
    @pulumi.getter(name="staticContext")
    def static_context(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Append the instance name instead of the branch to the status. Must enable to set a GitLab status check as *required* in GitHub. See [Static / dynamic status check names] to learn more.
        """
        return pulumi.get(self, "static_context")

    @static_context.setter
    def static_context(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "static_context", value)

    @_builtins.property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The title of this resource.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "title", value)

    @_builtins.property
    @pulumi.getter
    def token(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        A GitHub personal access token with at least the `repo:status` scope.
        """
        return pulumi.get(self, "token")

    @token.setter
    def token(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "token", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Update time.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)


@pulumi.type_token("gitlab:index/projectIntegrationGithub:ProjectIntegrationGithub")
class ProjectIntegrationGithub(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_url: Optional[pulumi.Input[_builtins.str]] = None,
                 static_context: Optional[pulumi.Input[_builtins.bool]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `ProjectIntegrationGithub` resource manages the lifecycle of a project integration with GitHub.

        > This resource requires a GitLab Enterprise instance.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/project_integrations/#github)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        awesome_project = gitlab.Project("awesome_project",
            name="awesome_project",
            description="My awesome project.",
            visibility_level="public")
        github = gitlab.ProjectIntegrationGithub("github",
            project=awesome_project.id,
            token="REDACTED",
            repository_url="https://github.com/gitlabhq/terraform-provider-gitlab")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_integration_github`. For example:

        terraform

        import {

          to = gitlab_project_integration_github.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        ```sh
        $ pulumi import gitlab:index/projectIntegrationGithub:ProjectIntegrationGithub You can import a gitlab_project_integration_github state using `<resource> <project_id>`:
        ```

        ```sh
        $ pulumi import gitlab:index/projectIntegrationGithub:ProjectIntegrationGithub github 1
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] project: ID of the project you want to activate the integration on.
        :param pulumi.Input[_builtins.bool] static_context: Append the instance name instead of the branch to the status. Must enable to set a GitLab status check as *required* in GitHub. See [Static / dynamic status check names] to learn more.
        :param pulumi.Input[_builtins.str] token: A GitHub personal access token with at least the `repo:status` scope.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectIntegrationGithubArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectIntegrationGithub` resource manages the lifecycle of a project integration with GitHub.

        > This resource requires a GitLab Enterprise instance.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/project_integrations/#github)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        awesome_project = gitlab.Project("awesome_project",
            name="awesome_project",
            description="My awesome project.",
            visibility_level="public")
        github = gitlab.ProjectIntegrationGithub("github",
            project=awesome_project.id,
            token="REDACTED",
            repository_url="https://github.com/gitlabhq/terraform-provider-gitlab")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_integration_github`. For example:

        terraform

        import {

          to = gitlab_project_integration_github.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        ```sh
        $ pulumi import gitlab:index/projectIntegrationGithub:ProjectIntegrationGithub You can import a gitlab_project_integration_github state using `<resource> <project_id>`:
        ```

        ```sh
        $ pulumi import gitlab:index/projectIntegrationGithub:ProjectIntegrationGithub github 1
        ```

        :param str resource_name: The name of the resource.
        :param ProjectIntegrationGithubArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectIntegrationGithubArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 repository_url: Optional[pulumi.Input[_builtins.str]] = None,
                 static_context: Optional[pulumi.Input[_builtins.bool]] = None,
                 token: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectIntegrationGithubArgs.__new__(ProjectIntegrationGithubArgs)

            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if repository_url is None and not opts.urn:
                raise TypeError("Missing required property 'repository_url'")
            __props__.__dict__["repository_url"] = repository_url
            __props__.__dict__["static_context"] = static_context
            if token is None and not opts.urn:
                raise TypeError("Missing required property 'token'")
            __props__.__dict__["token"] = None if token is None else pulumi.Output.secret(token)
            __props__.__dict__["active"] = None
            __props__.__dict__["created_at"] = None
            __props__.__dict__["title"] = None
            __props__.__dict__["updated_at"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["token"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(ProjectIntegrationGithub, __self__).__init__(
            'gitlab:index/projectIntegrationGithub:ProjectIntegrationGithub',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            active: Optional[pulumi.Input[_builtins.bool]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            repository_url: Optional[pulumi.Input[_builtins.str]] = None,
            static_context: Optional[pulumi.Input[_builtins.bool]] = None,
            title: Optional[pulumi.Input[_builtins.str]] = None,
            token: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None) -> 'ProjectIntegrationGithub':
        """
        Get an existing ProjectIntegrationGithub resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] active: Whether the integration is active.
        :param pulumi.Input[_builtins.str] created_at: Creation time.
        :param pulumi.Input[_builtins.str] project: ID of the project you want to activate the integration on.
        :param pulumi.Input[_builtins.bool] static_context: Append the instance name instead of the branch to the status. Must enable to set a GitLab status check as *required* in GitHub. See [Static / dynamic status check names] to learn more.
        :param pulumi.Input[_builtins.str] title: The title of this resource.
        :param pulumi.Input[_builtins.str] token: A GitHub personal access token with at least the `repo:status` scope.
        :param pulumi.Input[_builtins.str] updated_at: Update time.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectIntegrationGithubState.__new__(_ProjectIntegrationGithubState)

        __props__.__dict__["active"] = active
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["project"] = project
        __props__.__dict__["repository_url"] = repository_url
        __props__.__dict__["static_context"] = static_context
        __props__.__dict__["title"] = title
        __props__.__dict__["token"] = token
        __props__.__dict__["updated_at"] = updated_at
        return ProjectIntegrationGithub(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def active(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the integration is active.
        """
        return pulumi.get(self, "active")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        Creation time.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        ID of the project you want to activate the integration on.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="repositoryUrl")
    def repository_url(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "repository_url")

    @_builtins.property
    @pulumi.getter(name="staticContext")
    def static_context(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Append the instance name instead of the branch to the status. Must enable to set a GitLab status check as *required* in GitHub. See [Static / dynamic status check names] to learn more.
        """
        return pulumi.get(self, "static_context")

    @_builtins.property
    @pulumi.getter
    def title(self) -> pulumi.Output[_builtins.str]:
        """
        The title of this resource.
        """
        return pulumi.get(self, "title")

    @_builtins.property
    @pulumi.getter
    def token(self) -> pulumi.Output[_builtins.str]:
        """
        A GitHub personal access token with at least the `repo:status` scope.
        """
        return pulumi.get(self, "token")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        Update time.
        """
        return pulumi.get(self, "updated_at")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProjectAccessTokensResult',
    'AwaitableGetProjectAccessTokensResult',
    'get_project_access_tokens',
    'get_project_access_tokens_output',
]

@pulumi.output_type
class GetProjectAccessTokensResult:
    """
    A collection of values returned by getProjectAccessTokens.
    """
    def __init__(__self__, access_tokens=None, id=None, project=None, state=None):
        if access_tokens and not isinstance(access_tokens, list):
            raise TypeError("Expected argument 'access_tokens' to be a list")
        pulumi.set(__self__, "access_tokens", access_tokens)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)

    @_builtins.property
    @pulumi.getter(name="accessTokens")
    def access_tokens(self) -> Sequence['outputs.GetProjectAccessTokensAccessTokenResult']:
        """
        The list of access tokens returned by the search
        """
        return pulumi.get(self, "access_tokens")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def project(self) -> _builtins.str:
        """
        The name or id of the project.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[_builtins.str]:
        """
        List all project access token that match the specified state. Valid values are `active`, `inactive`. Returns all project access token if not set.
        """
        return pulumi.get(self, "state")


class AwaitableGetProjectAccessTokensResult(GetProjectAccessTokensResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectAccessTokensResult(
            access_tokens=self.access_tokens,
            id=self.id,
            project=self.project,
            state=self.state)


def get_project_access_tokens(project: Optional[_builtins.str] = None,
                              state: Optional[_builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectAccessTokensResult:
    """
    The `get_project_access_tokens` data source allows to retrieve all project access tokens for a given project.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/project_access_tokens/)


    :param _builtins.str project: The name or id of the project.
    :param _builtins.str state: List all project access token that match the specified state. Valid values are `active`, `inactive`. Returns all project access token if not set.
    """
    __args__ = dict()
    __args__['project'] = project
    __args__['state'] = state
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectAccessTokens:getProjectAccessTokens', __args__, opts=opts, typ=GetProjectAccessTokensResult).value

    return AwaitableGetProjectAccessTokensResult(
        access_tokens=pulumi.get(__ret__, 'access_tokens'),
        id=pulumi.get(__ret__, 'id'),
        project=pulumi.get(__ret__, 'project'),
        state=pulumi.get(__ret__, 'state'))
def get_project_access_tokens_output(project: Optional[pulumi.Input[_builtins.str]] = None,
                                     state: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectAccessTokensResult]:
    """
    The `get_project_access_tokens` data source allows to retrieve all project access tokens for a given project.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/project_access_tokens/)


    :param _builtins.str project: The name or id of the project.
    :param _builtins.str state: List all project access token that match the specified state. Valid values are `active`, `inactive`. Returns all project access token if not set.
    """
    __args__ = dict()
    __args__['project'] = project
    __args__['state'] = state
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectAccessTokens:getProjectAccessTokens', __args__, opts=opts, typ=GetProjectAccessTokensResult)
    return __ret__.apply(lambda __response__: GetProjectAccessTokensResult(
        access_tokens=pulumi.get(__response__, 'access_tokens'),
        id=pulumi.get(__response__, 'id'),
        project=pulumi.get(__response__, 'project'),
        state=pulumi.get(__response__, 'state')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetApplicationResult',
    'AwaitableGetApplicationResult',
    'get_application',
    'get_application_output',
]

@pulumi.output_type
class GetApplicationResult:
    """
    A collection of values returned by getApplication.
    """
    def __init__(__self__, application_id=None, confidential=None, id=None, name=None, redirect_url=None):
        if application_id and not isinstance(application_id, str):
            raise TypeError("Expected argument 'application_id' to be a str")
        pulumi.set(__self__, "application_id", application_id)
        if confidential and not isinstance(confidential, bool):
            raise TypeError("Expected argument 'confidential' to be a bool")
        pulumi.set(__self__, "confidential", confidential)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if redirect_url and not isinstance(redirect_url, str):
            raise TypeError("Expected argument 'redirect_url' to be a str")
        pulumi.set(__self__, "redirect_url", redirect_url)

    @_builtins.property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> _builtins.str:
        """
        Internal GitLab application id.
        """
        return pulumi.get(self, "application_id")

    @_builtins.property
    @pulumi.getter
    def confidential(self) -> _builtins.bool:
        """
        Indicates if the application is kept confidential.
        """
        return pulumi.get(self, "confidential")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        The name of the GitLab application.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="redirectUrl")
    def redirect_url(self) -> _builtins.str:
        """
        The redirect url of the application.
        """
        return pulumi.get(self, "redirect_url")


class AwaitableGetApplicationResult(GetApplicationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetApplicationResult(
            application_id=self.application_id,
            confidential=self.confidential,
            id=self.id,
            name=self.name,
            redirect_url=self.redirect_url)


def get_application(id: Optional[_builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetApplicationResult:
    """
    The `Application` data source retrieves information about a gitlab application.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/applications/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    oidc = gitlab.get_application(id="1")
    ```
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getApplication:getApplication', __args__, opts=opts, typ=GetApplicationResult).value

    return AwaitableGetApplicationResult(
        application_id=pulumi.get(__ret__, 'application_id'),
        confidential=pulumi.get(__ret__, 'confidential'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        redirect_url=pulumi.get(__ret__, 'redirect_url'))
def get_application_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetApplicationResult]:
    """
    The `Application` data source retrieves information about a gitlab application.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/applications/)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    oidc = gitlab.get_application(id="1")
    ```
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getApplication:getApplication', __args__, opts=opts, typ=GetApplicationResult)
    return __ret__.apply(lambda __response__: GetApplicationResult(
        application_id=pulumi.get(__response__, 'application_id'),
        confidential=pulumi.get(__response__, 'confidential'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        redirect_url=pulumi.get(__response__, 'redirect_url')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['GroupSecurityPolicyAttachmentArgs', 'GroupSecurityPolicyAttachment']

@pulumi.input_type
class GroupSecurityPolicyAttachmentArgs:
    def __init__(__self__, *,
                 group: pulumi.Input[_builtins.str],
                 policy_project: pulumi.Input[_builtins.str]):
        """
        The set of arguments for constructing a GroupSecurityPolicyAttachment resource.
        :param pulumi.Input[_builtins.str] group: The ID or Full Path of the group which will have the security policy project assigned to it.
        :param pulumi.Input[_builtins.str] policy_project: The ID or Full Path of the security policy project.
        """
        pulumi.set(__self__, "group", group)
        pulumi.set(__self__, "policy_project", policy_project)

    @_builtins.property
    @pulumi.getter
    def group(self) -> pulumi.Input[_builtins.str]:
        """
        The ID or Full Path of the group which will have the security policy project assigned to it.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "group", value)

    @_builtins.property
    @pulumi.getter(name="policyProject")
    def policy_project(self) -> pulumi.Input[_builtins.str]:
        """
        The ID or Full Path of the security policy project.
        """
        return pulumi.get(self, "policy_project")

    @policy_project.setter
    def policy_project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "policy_project", value)


@pulumi.input_type
class _GroupSecurityPolicyAttachmentState:
    def __init__(__self__, *,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 group_graphql_id: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_project: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_project_graphql_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering GroupSecurityPolicyAttachment resources.
        :param pulumi.Input[_builtins.str] group: The ID or Full Path of the group which will have the security policy project assigned to it.
        :param pulumi.Input[_builtins.str] group_graphql_id: The GraphQL ID of the group to which the security policty project will be attached.
        :param pulumi.Input[_builtins.str] policy_project: The ID or Full Path of the security policy project.
        :param pulumi.Input[_builtins.str] policy_project_graphql_id: The GraphQL ID of the security policy project.
        """
        if group is not None:
            pulumi.set(__self__, "group", group)
        if group_graphql_id is not None:
            pulumi.set(__self__, "group_graphql_id", group_graphql_id)
        if policy_project is not None:
            pulumi.set(__self__, "policy_project", policy_project)
        if policy_project_graphql_id is not None:
            pulumi.set(__self__, "policy_project_graphql_id", policy_project_graphql_id)

    @_builtins.property
    @pulumi.getter
    def group(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID or Full Path of the group which will have the security policy project assigned to it.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "group", value)

    @_builtins.property
    @pulumi.getter(name="groupGraphqlId")
    def group_graphql_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The GraphQL ID of the group to which the security policty project will be attached.
        """
        return pulumi.get(self, "group_graphql_id")

    @group_graphql_id.setter
    def group_graphql_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "group_graphql_id", value)

    @_builtins.property
    @pulumi.getter(name="policyProject")
    def policy_project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID or Full Path of the security policy project.
        """
        return pulumi.get(self, "policy_project")

    @policy_project.setter
    def policy_project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy_project", value)

    @_builtins.property
    @pulumi.getter(name="policyProjectGraphqlId")
    def policy_project_graphql_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The GraphQL ID of the security policy project.
        """
        return pulumi.get(self, "policy_project_graphql_id")

    @policy_project_graphql_id.setter
    def policy_project_graphql_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "policy_project_graphql_id", value)


@pulumi.type_token("gitlab:index/groupSecurityPolicyAttachment:GroupSecurityPolicyAttachment")
class GroupSecurityPolicyAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_project: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # This resource can be used to attach a security policy to a pre-existing group
        foo = gitlab.GroupSecurityPolicyAttachment("foo",
            group="1234",
            policy_project="4567")
        # Or Terraform can create a new project, add a policy to that project,
        # then attach that policy project to other groups.
        my_policy_project = gitlab.Project("my-policy-project", name="security-policy-project")
        policy_yml = gitlab.RepositoryFile("policy-yml",
            project=my_policy_project.id,
            file_path=".gitlab/security-policies/my-policy.yml",
            branch="master",
            encoding="text",
            content=\"\"\"---
        approval_policy:
        - name: test
        description: test
        enabled: true
        rules:
        - type: any_merge_request
            branch_type: protected
            commits: any
        approval_settings:
            block_branch_modification: true
            prevent_pushing_and_force_pushing: true
            prevent_approval_by_author: true
            prevent_approval_by_commit_author: true
            remove_approvals_with_new_commit: true
            require_password_to_approve: false
        fallback_behavior:
            fail: closed
        policy_scope:
          compliance_frameworks:
          - id: 1010101
          - id: 0101010
        actions:
        - type: send_bot_message
            enabled: true
        \"\"\")
        # Multiple policies can be attached to a single project by repeating this resource or using a `for_each`
        my_policy = gitlab.GroupSecurityPolicyAttachment("my-policy",
            group="1234",
            policy_project=my_policy_project.id)
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_group_security_policy_attachment`. For example:

        terraform

        import {

          to = gitlab_group_security_policy_attachment.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        GitLab group security policy attachments can be imported using an id made up of `group:policy_project_id` where the policy project ID is the project ID of the policy project, e.g.

        ```sh
        $ pulumi import gitlab:index/groupSecurityPolicyAttachment:GroupSecurityPolicyAttachment foo 1:2
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] group: The ID or Full Path of the group which will have the security policy project assigned to it.
        :param pulumi.Input[_builtins.str] policy_project: The ID or Full Path of the security policy project.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupSecurityPolicyAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        # This resource can be used to attach a security policy to a pre-existing group
        foo = gitlab.GroupSecurityPolicyAttachment("foo",
            group="1234",
            policy_project="4567")
        # Or Terraform can create a new project, add a policy to that project,
        # then attach that policy project to other groups.
        my_policy_project = gitlab.Project("my-policy-project", name="security-policy-project")
        policy_yml = gitlab.RepositoryFile("policy-yml",
            project=my_policy_project.id,
            file_path=".gitlab/security-policies/my-policy.yml",
            branch="master",
            encoding="text",
            content=\"\"\"---
        approval_policy:
        - name: test
        description: test
        enabled: true
        rules:
        - type: any_merge_request
            branch_type: protected
            commits: any
        approval_settings:
            block_branch_modification: true
            prevent_pushing_and_force_pushing: true
            prevent_approval_by_author: true
            prevent_approval_by_commit_author: true
            remove_approvals_with_new_commit: true
            require_password_to_approve: false
        fallback_behavior:
            fail: closed
        policy_scope:
          compliance_frameworks:
          - id: 1010101
          - id: 0101010
        actions:
        - type: send_bot_message
            enabled: true
        \"\"\")
        # Multiple policies can be attached to a single project by repeating this resource or using a `for_each`
        my_policy = gitlab.GroupSecurityPolicyAttachment("my-policy",
            group="1234",
            policy_project=my_policy_project.id)
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_group_security_policy_attachment`. For example:

        terraform

        import {

          to = gitlab_group_security_policy_attachment.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        GitLab group security policy attachments can be imported using an id made up of `group:policy_project_id` where the policy project ID is the project ID of the policy project, e.g.

        ```sh
        $ pulumi import gitlab:index/groupSecurityPolicyAttachment:GroupSecurityPolicyAttachment foo 1:2
        ```

        :param str resource_name: The name of the resource.
        :param GroupSecurityPolicyAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupSecurityPolicyAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 policy_project: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupSecurityPolicyAttachmentArgs.__new__(GroupSecurityPolicyAttachmentArgs)

            if group is None and not opts.urn:
                raise TypeError("Missing required property 'group'")
            __props__.__dict__["group"] = group
            if policy_project is None and not opts.urn:
                raise TypeError("Missing required property 'policy_project'")
            __props__.__dict__["policy_project"] = policy_project
            __props__.__dict__["group_graphql_id"] = None
            __props__.__dict__["policy_project_graphql_id"] = None
        super(GroupSecurityPolicyAttachment, __self__).__init__(
            'gitlab:index/groupSecurityPolicyAttachment:GroupSecurityPolicyAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            group: Optional[pulumi.Input[_builtins.str]] = None,
            group_graphql_id: Optional[pulumi.Input[_builtins.str]] = None,
            policy_project: Optional[pulumi.Input[_builtins.str]] = None,
            policy_project_graphql_id: Optional[pulumi.Input[_builtins.str]] = None) -> 'GroupSecurityPolicyAttachment':
        """
        Get an existing GroupSecurityPolicyAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] group: The ID or Full Path of the group which will have the security policy project assigned to it.
        :param pulumi.Input[_builtins.str] group_graphql_id: The GraphQL ID of the group to which the security policty project will be attached.
        :param pulumi.Input[_builtins.str] policy_project: The ID or Full Path of the security policy project.
        :param pulumi.Input[_builtins.str] policy_project_graphql_id: The GraphQL ID of the security policy project.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupSecurityPolicyAttachmentState.__new__(_GroupSecurityPolicyAttachmentState)

        __props__.__dict__["group"] = group
        __props__.__dict__["group_graphql_id"] = group_graphql_id
        __props__.__dict__["policy_project"] = policy_project
        __props__.__dict__["policy_project_graphql_id"] = policy_project_graphql_id
        return GroupSecurityPolicyAttachment(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def group(self) -> pulumi.Output[_builtins.str]:
        """
        The ID or Full Path of the group which will have the security policy project assigned to it.
        """
        return pulumi.get(self, "group")

    @_builtins.property
    @pulumi.getter(name="groupGraphqlId")
    def group_graphql_id(self) -> pulumi.Output[_builtins.str]:
        """
        The GraphQL ID of the group to which the security policty project will be attached.
        """
        return pulumi.get(self, "group_graphql_id")

    @_builtins.property
    @pulumi.getter(name="policyProject")
    def policy_project(self) -> pulumi.Output[_builtins.str]:
        """
        The ID or Full Path of the security policy project.
        """
        return pulumi.get(self, "policy_project")

    @_builtins.property
    @pulumi.getter(name="policyProjectGraphqlId")
    def policy_project_graphql_id(self) -> pulumi.Output[_builtins.str]:
        """
        The GraphQL ID of the security policy project.
        """
        return pulumi.get(self, "policy_project_graphql_id")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['GroupProtectedEnvironmentArgs', 'GroupProtectedEnvironment']

@pulumi.input_type
class GroupProtectedEnvironmentArgs:
    def __init__(__self__, *,
                 deploy_access_levels: pulumi.Input[Sequence[pulumi.Input['GroupProtectedEnvironmentDeployAccessLevelArgs']]],
                 environment: pulumi.Input[_builtins.str],
                 group: pulumi.Input[_builtins.str],
                 approval_rules: Optional[pulumi.Input[Sequence[pulumi.Input['GroupProtectedEnvironmentApprovalRuleArgs']]]] = None):
        """
        The set of arguments for constructing a GroupProtectedEnvironment resource.
        :param pulumi.Input[Sequence[pulumi.Input['GroupProtectedEnvironmentDeployAccessLevelArgs']]] deploy_access_levels: Array of access levels allowed to deploy, with each described by a hash. Elements in the `deploy_access_levels` should be one of `user_id`, `group_id` or `access_level`.
        :param pulumi.Input[_builtins.str] environment: The deployment tier of the environment.  Valid values are `production`, `staging`, `testing`, `development`, `other`.
        :param pulumi.Input[_builtins.str] group: The ID or full path of the group which the protected environment is created against.
        :param pulumi.Input[Sequence[pulumi.Input['GroupProtectedEnvironmentApprovalRuleArgs']]] approval_rules: Array of approval rules to deploy, with each described by a hash. Elements in the `approval_rules` should be one of `user_id`, `group_id` or `access_level`.
        """
        pulumi.set(__self__, "deploy_access_levels", deploy_access_levels)
        pulumi.set(__self__, "environment", environment)
        pulumi.set(__self__, "group", group)
        if approval_rules is not None:
            pulumi.set(__self__, "approval_rules", approval_rules)

    @_builtins.property
    @pulumi.getter(name="deployAccessLevels")
    def deploy_access_levels(self) -> pulumi.Input[Sequence[pulumi.Input['GroupProtectedEnvironmentDeployAccessLevelArgs']]]:
        """
        Array of access levels allowed to deploy, with each described by a hash. Elements in the `deploy_access_levels` should be one of `user_id`, `group_id` or `access_level`.
        """
        return pulumi.get(self, "deploy_access_levels")

    @deploy_access_levels.setter
    def deploy_access_levels(self, value: pulumi.Input[Sequence[pulumi.Input['GroupProtectedEnvironmentDeployAccessLevelArgs']]]):
        pulumi.set(self, "deploy_access_levels", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Input[_builtins.str]:
        """
        The deployment tier of the environment.  Valid values are `production`, `staging`, `testing`, `development`, `other`.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter
    def group(self) -> pulumi.Input[_builtins.str]:
        """
        The ID or full path of the group which the protected environment is created against.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "group", value)

    @_builtins.property
    @pulumi.getter(name="approvalRules")
    def approval_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupProtectedEnvironmentApprovalRuleArgs']]]]:
        """
        Array of approval rules to deploy, with each described by a hash. Elements in the `approval_rules` should be one of `user_id`, `group_id` or `access_level`.
        """
        return pulumi.get(self, "approval_rules")

    @approval_rules.setter
    def approval_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupProtectedEnvironmentApprovalRuleArgs']]]]):
        pulumi.set(self, "approval_rules", value)


@pulumi.input_type
class _GroupProtectedEnvironmentState:
    def __init__(__self__, *,
                 approval_rules: Optional[pulumi.Input[Sequence[pulumi.Input['GroupProtectedEnvironmentApprovalRuleArgs']]]] = None,
                 deploy_access_levels: Optional[pulumi.Input[Sequence[pulumi.Input['GroupProtectedEnvironmentDeployAccessLevelArgs']]]] = None,
                 environment: Optional[pulumi.Input[_builtins.str]] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering GroupProtectedEnvironment resources.
        :param pulumi.Input[Sequence[pulumi.Input['GroupProtectedEnvironmentApprovalRuleArgs']]] approval_rules: Array of approval rules to deploy, with each described by a hash. Elements in the `approval_rules` should be one of `user_id`, `group_id` or `access_level`.
        :param pulumi.Input[Sequence[pulumi.Input['GroupProtectedEnvironmentDeployAccessLevelArgs']]] deploy_access_levels: Array of access levels allowed to deploy, with each described by a hash. Elements in the `deploy_access_levels` should be one of `user_id`, `group_id` or `access_level`.
        :param pulumi.Input[_builtins.str] environment: The deployment tier of the environment.  Valid values are `production`, `staging`, `testing`, `development`, `other`.
        :param pulumi.Input[_builtins.str] group: The ID or full path of the group which the protected environment is created against.
        """
        if approval_rules is not None:
            pulumi.set(__self__, "approval_rules", approval_rules)
        if deploy_access_levels is not None:
            pulumi.set(__self__, "deploy_access_levels", deploy_access_levels)
        if environment is not None:
            pulumi.set(__self__, "environment", environment)
        if group is not None:
            pulumi.set(__self__, "group", group)

    @_builtins.property
    @pulumi.getter(name="approvalRules")
    def approval_rules(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupProtectedEnvironmentApprovalRuleArgs']]]]:
        """
        Array of approval rules to deploy, with each described by a hash. Elements in the `approval_rules` should be one of `user_id`, `group_id` or `access_level`.
        """
        return pulumi.get(self, "approval_rules")

    @approval_rules.setter
    def approval_rules(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupProtectedEnvironmentApprovalRuleArgs']]]]):
        pulumi.set(self, "approval_rules", value)

    @_builtins.property
    @pulumi.getter(name="deployAccessLevels")
    def deploy_access_levels(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['GroupProtectedEnvironmentDeployAccessLevelArgs']]]]:
        """
        Array of access levels allowed to deploy, with each described by a hash. Elements in the `deploy_access_levels` should be one of `user_id`, `group_id` or `access_level`.
        """
        return pulumi.get(self, "deploy_access_levels")

    @deploy_access_levels.setter
    def deploy_access_levels(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['GroupProtectedEnvironmentDeployAccessLevelArgs']]]]):
        pulumi.set(self, "deploy_access_levels", value)

    @_builtins.property
    @pulumi.getter
    def environment(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The deployment tier of the environment.  Valid values are `production`, `staging`, `testing`, `development`, `other`.
        """
        return pulumi.get(self, "environment")

    @environment.setter
    def environment(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "environment", value)

    @_builtins.property
    @pulumi.getter
    def group(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID or full path of the group which the protected environment is created against.
        """
        return pulumi.get(self, "group")

    @group.setter
    def group(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "group", value)


@pulumi.type_token("gitlab:index/groupProtectedEnvironment:GroupProtectedEnvironment")
class GroupProtectedEnvironment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 approval_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupProtectedEnvironmentApprovalRuleArgs', 'GroupProtectedEnvironmentApprovalRuleArgsDict']]]]] = None,
                 deploy_access_levels: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupProtectedEnvironmentDeployAccessLevelArgs', 'GroupProtectedEnvironmentDeployAccessLevelArgsDict']]]]] = None,
                 environment: Optional[pulumi.Input[_builtins.str]] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `GroupProtectedEnvironment` resource allows to manage the lifecycle of a protected environment in a group.

        > In order to use a user_id in the `deploy_access_levels` configuration,
           you need to make sure that users have access to the group with Maintainer role or higher.
           In order to use a group_id in the `deploy_access_levels` configuration,
           the group_id must be a sub-group under the given group.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/group_protected_environments/)

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_group_protected_environment`. For example:

        terraform

        import {

          to = gitlab_group_protected_environment.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        GitLab group protected environments can be imported using an id made up of `groupId:environmentName`, e.g.

        ```sh
        $ pulumi import gitlab:index/groupProtectedEnvironment:GroupProtectedEnvironment bar 123:production
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GroupProtectedEnvironmentApprovalRuleArgs', 'GroupProtectedEnvironmentApprovalRuleArgsDict']]]] approval_rules: Array of approval rules to deploy, with each described by a hash. Elements in the `approval_rules` should be one of `user_id`, `group_id` or `access_level`.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GroupProtectedEnvironmentDeployAccessLevelArgs', 'GroupProtectedEnvironmentDeployAccessLevelArgsDict']]]] deploy_access_levels: Array of access levels allowed to deploy, with each described by a hash. Elements in the `deploy_access_levels` should be one of `user_id`, `group_id` or `access_level`.
        :param pulumi.Input[_builtins.str] environment: The deployment tier of the environment.  Valid values are `production`, `staging`, `testing`, `development`, `other`.
        :param pulumi.Input[_builtins.str] group: The ID or full path of the group which the protected environment is created against.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: GroupProtectedEnvironmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `GroupProtectedEnvironment` resource allows to manage the lifecycle of a protected environment in a group.

        > In order to use a user_id in the `deploy_access_levels` configuration,
           you need to make sure that users have access to the group with Maintainer role or higher.
           In order to use a group_id in the `deploy_access_levels` configuration,
           the group_id must be a sub-group under the given group.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/group_protected_environments/)

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_group_protected_environment`. For example:

        terraform

        import {

          to = gitlab_group_protected_environment.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        GitLab group protected environments can be imported using an id made up of `groupId:environmentName`, e.g.

        ```sh
        $ pulumi import gitlab:index/groupProtectedEnvironment:GroupProtectedEnvironment bar 123:production
        ```

        :param str resource_name: The name of the resource.
        :param GroupProtectedEnvironmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(GroupProtectedEnvironmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 approval_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupProtectedEnvironmentApprovalRuleArgs', 'GroupProtectedEnvironmentApprovalRuleArgsDict']]]]] = None,
                 deploy_access_levels: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupProtectedEnvironmentDeployAccessLevelArgs', 'GroupProtectedEnvironmentDeployAccessLevelArgsDict']]]]] = None,
                 environment: Optional[pulumi.Input[_builtins.str]] = None,
                 group: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = GroupProtectedEnvironmentArgs.__new__(GroupProtectedEnvironmentArgs)

            __props__.__dict__["approval_rules"] = approval_rules
            if deploy_access_levels is None and not opts.urn:
                raise TypeError("Missing required property 'deploy_access_levels'")
            __props__.__dict__["deploy_access_levels"] = deploy_access_levels
            if environment is None and not opts.urn:
                raise TypeError("Missing required property 'environment'")
            __props__.__dict__["environment"] = environment
            if group is None and not opts.urn:
                raise TypeError("Missing required property 'group'")
            __props__.__dict__["group"] = group
        super(GroupProtectedEnvironment, __self__).__init__(
            'gitlab:index/groupProtectedEnvironment:GroupProtectedEnvironment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            approval_rules: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupProtectedEnvironmentApprovalRuleArgs', 'GroupProtectedEnvironmentApprovalRuleArgsDict']]]]] = None,
            deploy_access_levels: Optional[pulumi.Input[Sequence[pulumi.Input[Union['GroupProtectedEnvironmentDeployAccessLevelArgs', 'GroupProtectedEnvironmentDeployAccessLevelArgsDict']]]]] = None,
            environment: Optional[pulumi.Input[_builtins.str]] = None,
            group: Optional[pulumi.Input[_builtins.str]] = None) -> 'GroupProtectedEnvironment':
        """
        Get an existing GroupProtectedEnvironment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GroupProtectedEnvironmentApprovalRuleArgs', 'GroupProtectedEnvironmentApprovalRuleArgsDict']]]] approval_rules: Array of approval rules to deploy, with each described by a hash. Elements in the `approval_rules` should be one of `user_id`, `group_id` or `access_level`.
        :param pulumi.Input[Sequence[pulumi.Input[Union['GroupProtectedEnvironmentDeployAccessLevelArgs', 'GroupProtectedEnvironmentDeployAccessLevelArgsDict']]]] deploy_access_levels: Array of access levels allowed to deploy, with each described by a hash. Elements in the `deploy_access_levels` should be one of `user_id`, `group_id` or `access_level`.
        :param pulumi.Input[_builtins.str] environment: The deployment tier of the environment.  Valid values are `production`, `staging`, `testing`, `development`, `other`.
        :param pulumi.Input[_builtins.str] group: The ID or full path of the group which the protected environment is created against.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _GroupProtectedEnvironmentState.__new__(_GroupProtectedEnvironmentState)

        __props__.__dict__["approval_rules"] = approval_rules
        __props__.__dict__["deploy_access_levels"] = deploy_access_levels
        __props__.__dict__["environment"] = environment
        __props__.__dict__["group"] = group
        return GroupProtectedEnvironment(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="approvalRules")
    def approval_rules(self) -> pulumi.Output[Sequence['outputs.GroupProtectedEnvironmentApprovalRule']]:
        """
        Array of approval rules to deploy, with each described by a hash. Elements in the `approval_rules` should be one of `user_id`, `group_id` or `access_level`.
        """
        return pulumi.get(self, "approval_rules")

    @_builtins.property
    @pulumi.getter(name="deployAccessLevels")
    def deploy_access_levels(self) -> pulumi.Output[Sequence['outputs.GroupProtectedEnvironmentDeployAccessLevel']]:
        """
        Array of access levels allowed to deploy, with each described by a hash. Elements in the `deploy_access_levels` should be one of `user_id`, `group_id` or `access_level`.
        """
        return pulumi.get(self, "deploy_access_levels")

    @_builtins.property
    @pulumi.getter
    def environment(self) -> pulumi.Output[_builtins.str]:
        """
        The deployment tier of the environment.  Valid values are `production`, `staging`, `testing`, `development`, `other`.
        """
        return pulumi.get(self, "environment")

    @_builtins.property
    @pulumi.getter
    def group(self) -> pulumi.Output[_builtins.str]:
        """
        The ID or full path of the group which the protected environment is created against.
        """
        return pulumi.get(self, "group")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['ProjectWikiPageArgs', 'ProjectWikiPage']

@pulumi.input_type
class ProjectWikiPageArgs:
    def __init__(__self__, *,
                 content: pulumi.Input[_builtins.str],
                 project: pulumi.Input[_builtins.str],
                 title: pulumi.Input[_builtins.str],
                 format: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ProjectWikiPage resource.
        :param pulumi.Input[_builtins.str] content: Content of the wiki page. Must be at least 1 character long.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.str] title: Title of the wiki page.
        :param pulumi.Input[_builtins.str] format: Format of the wiki page (auto-generated if not provided). Valid values are: `markdown`, `rdoc`, `asciidoc`, `org`.
        """
        pulumi.set(__self__, "content", content)
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "title", title)
        if format is not None:
            pulumi.set(__self__, "format", format)

    @_builtins.property
    @pulumi.getter
    def content(self) -> pulumi.Input[_builtins.str]:
        """
        Content of the wiki page. Must be at least 1 character long.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "content", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def title(self) -> pulumi.Input[_builtins.str]:
        """
        Title of the wiki page.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "title", value)

    @_builtins.property
    @pulumi.getter
    def format(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Format of the wiki page (auto-generated if not provided). Valid values are: `markdown`, `rdoc`, `asciidoc`, `org`.
        """
        return pulumi.get(self, "format")

    @format.setter
    def format(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "format", value)


@pulumi.input_type
class _ProjectWikiPageState:
    def __init__(__self__, *,
                 content: Optional[pulumi.Input[_builtins.str]] = None,
                 encoding: Optional[pulumi.Input[_builtins.str]] = None,
                 format: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 slug: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProjectWikiPage resources.
        :param pulumi.Input[_builtins.str] content: Content of the wiki page. Must be at least 1 character long.
        :param pulumi.Input[_builtins.str] encoding: The encoding used for the wiki page content.
        :param pulumi.Input[_builtins.str] format: Format of the wiki page (auto-generated if not provided). Valid values are: `markdown`, `rdoc`, `asciidoc`, `org`.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.str] slug: Slug of the wiki page.
        :param pulumi.Input[_builtins.str] title: Title of the wiki page.
        """
        if content is not None:
            pulumi.set(__self__, "content", content)
        if encoding is not None:
            pulumi.set(__self__, "encoding", encoding)
        if format is not None:
            pulumi.set(__self__, "format", format)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if slug is not None:
            pulumi.set(__self__, "slug", slug)
        if title is not None:
            pulumi.set(__self__, "title", title)

    @_builtins.property
    @pulumi.getter
    def content(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Content of the wiki page. Must be at least 1 character long.
        """
        return pulumi.get(self, "content")

    @content.setter
    def content(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "content", value)

    @_builtins.property
    @pulumi.getter
    def encoding(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The encoding used for the wiki page content.
        """
        return pulumi.get(self, "encoding")

    @encoding.setter
    def encoding(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "encoding", value)

    @_builtins.property
    @pulumi.getter
    def format(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Format of the wiki page (auto-generated if not provided). Valid values are: `markdown`, `rdoc`, `asciidoc`, `org`.
        """
        return pulumi.get(self, "format")

    @format.setter
    def format(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "format", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def slug(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Slug of the wiki page.
        """
        return pulumi.get(self, "slug")

    @slug.setter
    def slug(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "slug", value)

    @_builtins.property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Title of the wiki page.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "title", value)


@pulumi.type_token("gitlab:index/projectWikiPage:ProjectWikiPage")
class ProjectWikiPage(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content: Optional[pulumi.Input[_builtins.str]] = None,
                 format: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `ProjectWikiPage` resource allows managing the lifecycle of a project wiki page.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/wikis/)

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_wiki_page`. For example:

        terraform

        import {

          to = gitlab_project_wiki_page.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        You can import gitlab_project_wiki_page state using the project ID, e.g.

        ```sh
        $ pulumi import gitlab:index/projectWikiPage:ProjectWikiPage test 12345:my-wiki-page
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] content: Content of the wiki page. Must be at least 1 character long.
        :param pulumi.Input[_builtins.str] format: Format of the wiki page (auto-generated if not provided). Valid values are: `markdown`, `rdoc`, `asciidoc`, `org`.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.str] title: Title of the wiki page.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectWikiPageArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `ProjectWikiPage` resource allows managing the lifecycle of a project wiki page.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/wikis/)

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_wiki_page`. For example:

        terraform

        import {

          to = gitlab_project_wiki_page.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        You can import gitlab_project_wiki_page state using the project ID, e.g.

        ```sh
        $ pulumi import gitlab:index/projectWikiPage:ProjectWikiPage test 12345:my-wiki-page
        ```

        :param str resource_name: The name of the resource.
        :param ProjectWikiPageArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectWikiPageArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 content: Optional[pulumi.Input[_builtins.str]] = None,
                 format: Optional[pulumi.Input[_builtins.str]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectWikiPageArgs.__new__(ProjectWikiPageArgs)

            if content is None and not opts.urn:
                raise TypeError("Missing required property 'content'")
            __props__.__dict__["content"] = content
            __props__.__dict__["format"] = format
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if title is None and not opts.urn:
                raise TypeError("Missing required property 'title'")
            __props__.__dict__["title"] = title
            __props__.__dict__["encoding"] = None
            __props__.__dict__["slug"] = None
        super(ProjectWikiPage, __self__).__init__(
            'gitlab:index/projectWikiPage:ProjectWikiPage',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            content: Optional[pulumi.Input[_builtins.str]] = None,
            encoding: Optional[pulumi.Input[_builtins.str]] = None,
            format: Optional[pulumi.Input[_builtins.str]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            slug: Optional[pulumi.Input[_builtins.str]] = None,
            title: Optional[pulumi.Input[_builtins.str]] = None) -> 'ProjectWikiPage':
        """
        Get an existing ProjectWikiPage resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] content: Content of the wiki page. Must be at least 1 character long.
        :param pulumi.Input[_builtins.str] encoding: The encoding used for the wiki page content.
        :param pulumi.Input[_builtins.str] format: Format of the wiki page (auto-generated if not provided). Valid values are: `markdown`, `rdoc`, `asciidoc`, `org`.
        :param pulumi.Input[_builtins.str] project: The ID or URL-encoded path of the project.
        :param pulumi.Input[_builtins.str] slug: Slug of the wiki page.
        :param pulumi.Input[_builtins.str] title: Title of the wiki page.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectWikiPageState.__new__(_ProjectWikiPageState)

        __props__.__dict__["content"] = content
        __props__.__dict__["encoding"] = encoding
        __props__.__dict__["format"] = format
        __props__.__dict__["project"] = project
        __props__.__dict__["slug"] = slug
        __props__.__dict__["title"] = title
        return ProjectWikiPage(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def content(self) -> pulumi.Output[_builtins.str]:
        """
        Content of the wiki page. Must be at least 1 character long.
        """
        return pulumi.get(self, "content")

    @_builtins.property
    @pulumi.getter
    def encoding(self) -> pulumi.Output[_builtins.str]:
        """
        The encoding used for the wiki page content.
        """
        return pulumi.get(self, "encoding")

    @_builtins.property
    @pulumi.getter
    def format(self) -> pulumi.Output[_builtins.str]:
        """
        Format of the wiki page (auto-generated if not provided). Valid values are: `markdown`, `rdoc`, `asciidoc`, `org`.
        """
        return pulumi.get(self, "format")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        The ID or URL-encoded path of the project.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter
    def slug(self) -> pulumi.Output[_builtins.str]:
        """
        Slug of the wiki page.
        """
        return pulumi.get(self, "slug")

    @_builtins.property
    @pulumi.getter
    def title(self) -> pulumi.Output[_builtins.str]:
        """
        Title of the wiki page.
        """
        return pulumi.get(self, "title")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['PipelineScheduleVariableArgs', 'PipelineScheduleVariable']

@pulumi.input_type
class PipelineScheduleVariableArgs:
    def __init__(__self__, *,
                 key: pulumi.Input[_builtins.str],
                 pipeline_schedule_id: pulumi.Input[_builtins.int],
                 project: pulumi.Input[_builtins.str],
                 value: pulumi.Input[_builtins.str],
                 variable_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a PipelineScheduleVariable resource.
        :param pulumi.Input[_builtins.str] key: Name of the variable.
        :param pulumi.Input[_builtins.int] pipeline_schedule_id: The id of the pipeline schedule.
        :param pulumi.Input[_builtins.str] project: The id of the project to add the schedule to.
        :param pulumi.Input[_builtins.str] value: Value of the variable.
        :param pulumi.Input[_builtins.str] variable_type: The type of a variable. Available types are: `env_var`, `file`. Default is `env_var`.
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "pipeline_schedule_id", pipeline_schedule_id)
        pulumi.set(__self__, "project", project)
        pulumi.set(__self__, "value", value)
        if variable_type is not None:
            pulumi.set(__self__, "variable_type", variable_type)

    @_builtins.property
    @pulumi.getter
    def key(self) -> pulumi.Input[_builtins.str]:
        """
        Name of the variable.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter(name="pipelineScheduleId")
    def pipeline_schedule_id(self) -> pulumi.Input[_builtins.int]:
        """
        The id of the pipeline schedule.
        """
        return pulumi.get(self, "pipeline_schedule_id")

    @pipeline_schedule_id.setter
    def pipeline_schedule_id(self, value: pulumi.Input[_builtins.int]):
        pulumi.set(self, "pipeline_schedule_id", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the project to add the schedule to.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Input[_builtins.str]:
        """
        Value of the variable.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter(name="variableType")
    def variable_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of a variable. Available types are: `env_var`, `file`. Default is `env_var`.
        """
        return pulumi.get(self, "variable_type")

    @variable_type.setter
    def variable_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "variable_type", value)


@pulumi.input_type
class _PipelineScheduleVariableState:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_schedule_id: Optional[pulumi.Input[_builtins.int]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 variable_type: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering PipelineScheduleVariable resources.
        :param pulumi.Input[_builtins.str] key: Name of the variable.
        :param pulumi.Input[_builtins.int] pipeline_schedule_id: The id of the pipeline schedule.
        :param pulumi.Input[_builtins.str] project: The id of the project to add the schedule to.
        :param pulumi.Input[_builtins.str] value: Value of the variable.
        :param pulumi.Input[_builtins.str] variable_type: The type of a variable. Available types are: `env_var`, `file`. Default is `env_var`.
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if pipeline_schedule_id is not None:
            pulumi.set(__self__, "pipeline_schedule_id", pipeline_schedule_id)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if variable_type is not None:
            pulumi.set(__self__, "variable_type", variable_type)

    @_builtins.property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the variable.
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "key", value)

    @_builtins.property
    @pulumi.getter(name="pipelineScheduleId")
    def pipeline_schedule_id(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        The id of the pipeline schedule.
        """
        return pulumi.get(self, "pipeline_schedule_id")

    @pipeline_schedule_id.setter
    def pipeline_schedule_id(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "pipeline_schedule_id", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the project to add the schedule to.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Value of the variable.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "value", value)

    @_builtins.property
    @pulumi.getter(name="variableType")
    def variable_type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The type of a variable. Available types are: `env_var`, `file`. Default is `env_var`.
        """
        return pulumi.get(self, "variable_type")

    @variable_type.setter
    def variable_type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "variable_type", value)


@pulumi.type_token("gitlab:index/pipelineScheduleVariable:PipelineScheduleVariable")
class PipelineScheduleVariable(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_schedule_id: Optional[pulumi.Input[_builtins.int]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 variable_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        The `PipelineScheduleVariable` resource allows to manage the lifecycle of a variable for a pipeline schedule.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/pipeline_schedules/#pipeline-schedule-variables)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.PipelineSchedule("example",
            project="12345",
            description="Used to schedule builds",
            ref="master",
            cron="0 1 * * *")
        example_pipeline_schedule_variable = gitlab.PipelineScheduleVariable("example",
            project=example.project,
            pipeline_schedule_id=example.pipeline_schedule_id,
            key="EXAMPLE_KEY",
            value="example")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_pipeline_schedule_variable`. For example:

        terraform

        import {

          to = gitlab_pipeline_schedule_variable.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        Pipeline schedule variables can be imported using an id made up of `project_id:pipeline_schedule_id:key`, e.g.

        ```sh
        $ pulumi import gitlab:index/pipelineScheduleVariable:PipelineScheduleVariable example 123456789:13:mykey
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] key: Name of the variable.
        :param pulumi.Input[_builtins.int] pipeline_schedule_id: The id of the pipeline schedule.
        :param pulumi.Input[_builtins.str] project: The id of the project to add the schedule to.
        :param pulumi.Input[_builtins.str] value: Value of the variable.
        :param pulumi.Input[_builtins.str] variable_type: The type of a variable. Available types are: `env_var`, `file`. Default is `env_var`.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PipelineScheduleVariableArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        The `PipelineScheduleVariable` resource allows to manage the lifecycle of a variable for a pipeline schedule.

        **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/pipeline_schedules/#pipeline-schedule-variables)

        ## Example Usage

        ```python
        import pulumi
        import pulumi_gitlab as gitlab

        example = gitlab.PipelineSchedule("example",
            project="12345",
            description="Used to schedule builds",
            ref="master",
            cron="0 1 * * *")
        example_pipeline_schedule_variable = gitlab.PipelineScheduleVariable("example",
            project=example.project,
            pipeline_schedule_id=example.pipeline_schedule_id,
            key="EXAMPLE_KEY",
            value="example")
        ```

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_pipeline_schedule_variable`. For example:

        terraform

        import {

          to = gitlab_pipeline_schedule_variable.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        Pipeline schedule variables can be imported using an id made up of `project_id:pipeline_schedule_id:key`, e.g.

        ```sh
        $ pulumi import gitlab:index/pipelineScheduleVariable:PipelineScheduleVariable example 123456789:13:mykey
        ```

        :param str resource_name: The name of the resource.
        :param PipelineScheduleVariableArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PipelineScheduleVariableArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 key: Optional[pulumi.Input[_builtins.str]] = None,
                 pipeline_schedule_id: Optional[pulumi.Input[_builtins.int]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 value: Optional[pulumi.Input[_builtins.str]] = None,
                 variable_type: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PipelineScheduleVariableArgs.__new__(PipelineScheduleVariableArgs)

            if key is None and not opts.urn:
                raise TypeError("Missing required property 'key'")
            __props__.__dict__["key"] = key
            if pipeline_schedule_id is None and not opts.urn:
                raise TypeError("Missing required property 'pipeline_schedule_id'")
            __props__.__dict__["pipeline_schedule_id"] = pipeline_schedule_id
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            if value is None and not opts.urn:
                raise TypeError("Missing required property 'value'")
            __props__.__dict__["value"] = value
            __props__.__dict__["variable_type"] = variable_type
        super(PipelineScheduleVariable, __self__).__init__(
            'gitlab:index/pipelineScheduleVariable:PipelineScheduleVariable',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            key: Optional[pulumi.Input[_builtins.str]] = None,
            pipeline_schedule_id: Optional[pulumi.Input[_builtins.int]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            value: Optional[pulumi.Input[_builtins.str]] = None,
            variable_type: Optional[pulumi.Input[_builtins.str]] = None) -> 'PipelineScheduleVariable':
        """
        Get an existing PipelineScheduleVariable resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] key: Name of the variable.
        :param pulumi.Input[_builtins.int] pipeline_schedule_id: The id of the pipeline schedule.
        :param pulumi.Input[_builtins.str] project: The id of the project to add the schedule to.
        :param pulumi.Input[_builtins.str] value: Value of the variable.
        :param pulumi.Input[_builtins.str] variable_type: The type of a variable. Available types are: `env_var`, `file`. Default is `env_var`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PipelineScheduleVariableState.__new__(_PipelineScheduleVariableState)

        __props__.__dict__["key"] = key
        __props__.__dict__["pipeline_schedule_id"] = pipeline_schedule_id
        __props__.__dict__["project"] = project
        __props__.__dict__["value"] = value
        __props__.__dict__["variable_type"] = variable_type
        return PipelineScheduleVariable(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def key(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the variable.
        """
        return pulumi.get(self, "key")

    @_builtins.property
    @pulumi.getter(name="pipelineScheduleId")
    def pipeline_schedule_id(self) -> pulumi.Output[_builtins.int]:
        """
        The id of the pipeline schedule.
        """
        return pulumi.get(self, "pipeline_schedule_id")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the project to add the schedule to.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter
    def value(self) -> pulumi.Output[_builtins.str]:
        """
        Value of the variable.
        """
        return pulumi.get(self, "value")

    @_builtins.property
    @pulumi.getter(name="variableType")
    def variable_type(self) -> pulumi.Output[_builtins.str]:
        """
        The type of a variable. Available types are: `env_var`, `file`. Default is `env_var`.
        """
        return pulumi.get(self, "variable_type")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetProjectMergeRequestsResult',
    'AwaitableGetProjectMergeRequestsResult',
    'get_project_merge_requests',
    'get_project_merge_requests_output',
]

@pulumi.output_type
class GetProjectMergeRequestsResult:
    """
    A collection of values returned by getProjectMergeRequests.
    """
    def __init__(__self__, author_id=None, author_username=None, created_after=None, created_before=None, id=None, iids=None, merge_requests=None, milestone=None, my_reaction_emoji=None, order_by=None, project=None, reviewer_username=None, scope=None, search=None, sort=None, source_branch=None, state=None, target_branch=None, updated_after=None, updated_before=None, wip=None):
        if author_id and not isinstance(author_id, int):
            raise TypeError("Expected argument 'author_id' to be a int")
        pulumi.set(__self__, "author_id", author_id)
        if author_username and not isinstance(author_username, str):
            raise TypeError("Expected argument 'author_username' to be a str")
        pulumi.set(__self__, "author_username", author_username)
        if created_after and not isinstance(created_after, str):
            raise TypeError("Expected argument 'created_after' to be a str")
        pulumi.set(__self__, "created_after", created_after)
        if created_before and not isinstance(created_before, str):
            raise TypeError("Expected argument 'created_before' to be a str")
        pulumi.set(__self__, "created_before", created_before)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if iids and not isinstance(iids, list):
            raise TypeError("Expected argument 'iids' to be a list")
        pulumi.set(__self__, "iids", iids)
        if merge_requests and not isinstance(merge_requests, list):
            raise TypeError("Expected argument 'merge_requests' to be a list")
        pulumi.set(__self__, "merge_requests", merge_requests)
        if milestone and not isinstance(milestone, str):
            raise TypeError("Expected argument 'milestone' to be a str")
        pulumi.set(__self__, "milestone", milestone)
        if my_reaction_emoji and not isinstance(my_reaction_emoji, str):
            raise TypeError("Expected argument 'my_reaction_emoji' to be a str")
        pulumi.set(__self__, "my_reaction_emoji", my_reaction_emoji)
        if order_by and not isinstance(order_by, str):
            raise TypeError("Expected argument 'order_by' to be a str")
        pulumi.set(__self__, "order_by", order_by)
        if project and not isinstance(project, str):
            raise TypeError("Expected argument 'project' to be a str")
        pulumi.set(__self__, "project", project)
        if reviewer_username and not isinstance(reviewer_username, str):
            raise TypeError("Expected argument 'reviewer_username' to be a str")
        pulumi.set(__self__, "reviewer_username", reviewer_username)
        if scope and not isinstance(scope, str):
            raise TypeError("Expected argument 'scope' to be a str")
        pulumi.set(__self__, "scope", scope)
        if search and not isinstance(search, str):
            raise TypeError("Expected argument 'search' to be a str")
        pulumi.set(__self__, "search", search)
        if sort and not isinstance(sort, str):
            raise TypeError("Expected argument 'sort' to be a str")
        pulumi.set(__self__, "sort", sort)
        if source_branch and not isinstance(source_branch, str):
            raise TypeError("Expected argument 'source_branch' to be a str")
        pulumi.set(__self__, "source_branch", source_branch)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if target_branch and not isinstance(target_branch, str):
            raise TypeError("Expected argument 'target_branch' to be a str")
        pulumi.set(__self__, "target_branch", target_branch)
        if updated_after and not isinstance(updated_after, str):
            raise TypeError("Expected argument 'updated_after' to be a str")
        pulumi.set(__self__, "updated_after", updated_after)
        if updated_before and not isinstance(updated_before, str):
            raise TypeError("Expected argument 'updated_before' to be a str")
        pulumi.set(__self__, "updated_before", updated_before)
        if wip and not isinstance(wip, str):
            raise TypeError("Expected argument 'wip' to be a str")
        pulumi.set(__self__, "wip", wip)

    @_builtins.property
    @pulumi.getter(name="authorId")
    def author_id(self) -> Optional[_builtins.int]:
        """
        Return merge requests created by the given user ID.
        """
        return pulumi.get(self, "author_id")

    @_builtins.property
    @pulumi.getter(name="authorUsername")
    def author_username(self) -> Optional[_builtins.str]:
        """
        Return merge requests created by the given username.
        """
        return pulumi.get(self, "author_username")

    @_builtins.property
    @pulumi.getter(name="createdAfter")
    def created_after(self) -> Optional[_builtins.str]:
        """
        Return merge requests created after the given time. Expected in RFC3339 format (2006-01-02T15:04:05Z).
        """
        return pulumi.get(self, "created_after")

    @_builtins.property
    @pulumi.getter(name="createdBefore")
    def created_before(self) -> Optional[_builtins.str]:
        """
        Return merge requests created before the given time. Expected in RFC3339 format (2006-01-02T15:04:05Z).
        """
        return pulumi.get(self, "created_before")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def iids(self) -> Optional[Sequence[_builtins.int]]:
        """
        The unique internal IDs of the merge requests.
        """
        return pulumi.get(self, "iids")

    @_builtins.property
    @pulumi.getter(name="mergeRequests")
    def merge_requests(self) -> Sequence['outputs.GetProjectMergeRequestsMergeRequestResult']:
        """
        The list of merge requests.
        """
        return pulumi.get(self, "merge_requests")

    @_builtins.property
    @pulumi.getter
    def milestone(self) -> Optional[_builtins.str]:
        """
        Return only merge requests for a specific milestone. `None` returns merge requests with no milestone. `Any` returns merge requests that have an assigned milestone.
        """
        return pulumi.get(self, "milestone")

    @_builtins.property
    @pulumi.getter(name="myReactionEmoji")
    def my_reaction_emoji(self) -> Optional[_builtins.str]:
        """
        Return merge requests reacted to by the authenticated user with the given emoji. `None` returns issues not given a reaction. `Any` returns issues given at least one reaction.
        """
        return pulumi.get(self, "my_reaction_emoji")

    @_builtins.property
    @pulumi.getter(name="orderBy")
    def order_by(self) -> Optional[_builtins.str]:
        """
        Return requests ordered by `created_at`, `title` or `updated_at`. Default is `created_at`.
        """
        return pulumi.get(self, "order_by")

    @_builtins.property
    @pulumi.getter
    def project(self) -> _builtins.str:
        """
        The ID or path of the project.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter(name="reviewerUsername")
    def reviewer_username(self) -> Optional[_builtins.str]:
        """
        Return merge requests reviewed by the given username. `None` returns merge requests with no reviews. `Any` returns merge requests with any reviewer.
        """
        return pulumi.get(self, "reviewer_username")

    @_builtins.property
    @pulumi.getter
    def scope(self) -> Optional[_builtins.str]:
        """
        Return merge requests for the given scope: `created_by_me`, `assigned_to_me`, or `all`.
        """
        return pulumi.get(self, "scope")

    @_builtins.property
    @pulumi.getter
    def search(self) -> Optional[_builtins.str]:
        """
        Search merge requests against their `title` or `description`.
        """
        return pulumi.get(self, "search")

    @_builtins.property
    @pulumi.getter
    def sort(self) -> Optional[_builtins.str]:
        """
        Return requests sorted in `asc` or `desc` order. Default is `desc`.
        """
        return pulumi.get(self, "sort")

    @_builtins.property
    @pulumi.getter(name="sourceBranch")
    def source_branch(self) -> Optional[_builtins.str]:
        """
        Return merge requests with the given source branch.
        """
        return pulumi.get(self, "source_branch")

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[_builtins.str]:
        """
        Return all merge requests (all) or just those that are opened, closed, locked, or merged.
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter(name="targetBranch")
    def target_branch(self) -> Optional[_builtins.str]:
        """
        Return merge requests with the given target branch.
        """
        return pulumi.get(self, "target_branch")

    @_builtins.property
    @pulumi.getter(name="updatedAfter")
    def updated_after(self) -> Optional[_builtins.str]:
        """
        Return merge requests updated after the given time. Expected in RFC3339 format (2006-01-02T15:04:05Z).
        """
        return pulumi.get(self, "updated_after")

    @_builtins.property
    @pulumi.getter(name="updatedBefore")
    def updated_before(self) -> Optional[_builtins.str]:
        """
        Return merge requests updated before the given time. Expected in RFC3339 format (2006-01-02T15:04:05Z).
        """
        return pulumi.get(self, "updated_before")

    @_builtins.property
    @pulumi.getter
    def wip(self) -> Optional[_builtins.str]:
        """
        Filter merge requests against their wip status. `yes` to return only draft merge requests, `no` to return non-draft merge requests.
        """
        return pulumi.get(self, "wip")


class AwaitableGetProjectMergeRequestsResult(GetProjectMergeRequestsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetProjectMergeRequestsResult(
            author_id=self.author_id,
            author_username=self.author_username,
            created_after=self.created_after,
            created_before=self.created_before,
            id=self.id,
            iids=self.iids,
            merge_requests=self.merge_requests,
            milestone=self.milestone,
            my_reaction_emoji=self.my_reaction_emoji,
            order_by=self.order_by,
            project=self.project,
            reviewer_username=self.reviewer_username,
            scope=self.scope,
            search=self.search,
            sort=self.sort,
            source_branch=self.source_branch,
            state=self.state,
            target_branch=self.target_branch,
            updated_after=self.updated_after,
            updated_before=self.updated_before,
            wip=self.wip)


def get_project_merge_requests(author_id: Optional[_builtins.int] = None,
                               author_username: Optional[_builtins.str] = None,
                               created_after: Optional[_builtins.str] = None,
                               created_before: Optional[_builtins.str] = None,
                               iids: Optional[Sequence[_builtins.int]] = None,
                               milestone: Optional[_builtins.str] = None,
                               my_reaction_emoji: Optional[_builtins.str] = None,
                               order_by: Optional[_builtins.str] = None,
                               project: Optional[_builtins.str] = None,
                               reviewer_username: Optional[_builtins.str] = None,
                               scope: Optional[_builtins.str] = None,
                               search: Optional[_builtins.str] = None,
                               sort: Optional[_builtins.str] = None,
                               source_branch: Optional[_builtins.str] = None,
                               state: Optional[_builtins.str] = None,
                               target_branch: Optional[_builtins.str] = None,
                               updated_after: Optional[_builtins.str] = None,
                               updated_before: Optional[_builtins.str] = None,
                               wip: Optional[_builtins.str] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetProjectMergeRequestsResult:
    """
    The `get_project_merge_requests` data source retrieves
    information about a list of merge requests related to a specific project.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/merge_requests/#list-project-merge-requests)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example_one = gitlab.get_project_merge_requests(project="123",
        target_branch="main",
        wip="yes")
    example_two = gitlab.get_project_merge_requests(project="company/group/project1",
        author_id=5,
        created_after="2024-07-25T12:00:00Z")
    ```


    :param _builtins.int author_id: Return merge requests created by the given user ID.
    :param _builtins.str author_username: Return merge requests created by the given username.
    :param _builtins.str created_after: Return merge requests created after the given time. Expected in RFC3339 format (2006-01-02T15:04:05Z).
    :param _builtins.str created_before: Return merge requests created before the given time. Expected in RFC3339 format (2006-01-02T15:04:05Z).
    :param Sequence[_builtins.int] iids: The unique internal IDs of the merge requests.
    :param _builtins.str milestone: Return only merge requests for a specific milestone. `None` returns merge requests with no milestone. `Any` returns merge requests that have an assigned milestone.
    :param _builtins.str my_reaction_emoji: Return merge requests reacted to by the authenticated user with the given emoji. `None` returns issues not given a reaction. `Any` returns issues given at least one reaction.
    :param _builtins.str order_by: Return requests ordered by `created_at`, `title` or `updated_at`. Default is `created_at`.
    :param _builtins.str project: The ID or path of the project.
    :param _builtins.str reviewer_username: Return merge requests reviewed by the given username. `None` returns merge requests with no reviews. `Any` returns merge requests with any reviewer.
    :param _builtins.str scope: Return merge requests for the given scope: `created_by_me`, `assigned_to_me`, or `all`.
    :param _builtins.str search: Search merge requests against their `title` or `description`.
    :param _builtins.str sort: Return requests sorted in `asc` or `desc` order. Default is `desc`.
    :param _builtins.str source_branch: Return merge requests with the given source branch.
    :param _builtins.str state: Return all merge requests (all) or just those that are opened, closed, locked, or merged.
    :param _builtins.str target_branch: Return merge requests with the given target branch.
    :param _builtins.str updated_after: Return merge requests updated after the given time. Expected in RFC3339 format (2006-01-02T15:04:05Z).
    :param _builtins.str updated_before: Return merge requests updated before the given time. Expected in RFC3339 format (2006-01-02T15:04:05Z).
    :param _builtins.str wip: Filter merge requests against their wip status. `yes` to return only draft merge requests, `no` to return non-draft merge requests.
    """
    __args__ = dict()
    __args__['authorId'] = author_id
    __args__['authorUsername'] = author_username
    __args__['createdAfter'] = created_after
    __args__['createdBefore'] = created_before
    __args__['iids'] = iids
    __args__['milestone'] = milestone
    __args__['myReactionEmoji'] = my_reaction_emoji
    __args__['orderBy'] = order_by
    __args__['project'] = project
    __args__['reviewerUsername'] = reviewer_username
    __args__['scope'] = scope
    __args__['search'] = search
    __args__['sort'] = sort
    __args__['sourceBranch'] = source_branch
    __args__['state'] = state
    __args__['targetBranch'] = target_branch
    __args__['updatedAfter'] = updated_after
    __args__['updatedBefore'] = updated_before
    __args__['wip'] = wip
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('gitlab:index/getProjectMergeRequests:getProjectMergeRequests', __args__, opts=opts, typ=GetProjectMergeRequestsResult).value

    return AwaitableGetProjectMergeRequestsResult(
        author_id=pulumi.get(__ret__, 'author_id'),
        author_username=pulumi.get(__ret__, 'author_username'),
        created_after=pulumi.get(__ret__, 'created_after'),
        created_before=pulumi.get(__ret__, 'created_before'),
        id=pulumi.get(__ret__, 'id'),
        iids=pulumi.get(__ret__, 'iids'),
        merge_requests=pulumi.get(__ret__, 'merge_requests'),
        milestone=pulumi.get(__ret__, 'milestone'),
        my_reaction_emoji=pulumi.get(__ret__, 'my_reaction_emoji'),
        order_by=pulumi.get(__ret__, 'order_by'),
        project=pulumi.get(__ret__, 'project'),
        reviewer_username=pulumi.get(__ret__, 'reviewer_username'),
        scope=pulumi.get(__ret__, 'scope'),
        search=pulumi.get(__ret__, 'search'),
        sort=pulumi.get(__ret__, 'sort'),
        source_branch=pulumi.get(__ret__, 'source_branch'),
        state=pulumi.get(__ret__, 'state'),
        target_branch=pulumi.get(__ret__, 'target_branch'),
        updated_after=pulumi.get(__ret__, 'updated_after'),
        updated_before=pulumi.get(__ret__, 'updated_before'),
        wip=pulumi.get(__ret__, 'wip'))
def get_project_merge_requests_output(author_id: Optional[pulumi.Input[Optional[_builtins.int]]] = None,
                                      author_username: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      created_after: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      created_before: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      iids: Optional[pulumi.Input[Optional[Sequence[_builtins.int]]]] = None,
                                      milestone: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      my_reaction_emoji: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      order_by: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      project: Optional[pulumi.Input[_builtins.str]] = None,
                                      reviewer_username: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      scope: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      search: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      sort: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      source_branch: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      state: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      target_branch: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      updated_after: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      updated_before: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      wip: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                      opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetProjectMergeRequestsResult]:
    """
    The `get_project_merge_requests` data source retrieves
    information about a list of merge requests related to a specific project.

    **Upstream API**: [GitLab REST API docs](https://docs.gitlab.com/api/merge_requests/#list-project-merge-requests)

    ## Example Usage

    ```python
    import pulumi
    import pulumi_gitlab as gitlab

    example_one = gitlab.get_project_merge_requests(project="123",
        target_branch="main",
        wip="yes")
    example_two = gitlab.get_project_merge_requests(project="company/group/project1",
        author_id=5,
        created_after="2024-07-25T12:00:00Z")
    ```


    :param _builtins.int author_id: Return merge requests created by the given user ID.
    :param _builtins.str author_username: Return merge requests created by the given username.
    :param _builtins.str created_after: Return merge requests created after the given time. Expected in RFC3339 format (2006-01-02T15:04:05Z).
    :param _builtins.str created_before: Return merge requests created before the given time. Expected in RFC3339 format (2006-01-02T15:04:05Z).
    :param Sequence[_builtins.int] iids: The unique internal IDs of the merge requests.
    :param _builtins.str milestone: Return only merge requests for a specific milestone. `None` returns merge requests with no milestone. `Any` returns merge requests that have an assigned milestone.
    :param _builtins.str my_reaction_emoji: Return merge requests reacted to by the authenticated user with the given emoji. `None` returns issues not given a reaction. `Any` returns issues given at least one reaction.
    :param _builtins.str order_by: Return requests ordered by `created_at`, `title` or `updated_at`. Default is `created_at`.
    :param _builtins.str project: The ID or path of the project.
    :param _builtins.str reviewer_username: Return merge requests reviewed by the given username. `None` returns merge requests with no reviews. `Any` returns merge requests with any reviewer.
    :param _builtins.str scope: Return merge requests for the given scope: `created_by_me`, `assigned_to_me`, or `all`.
    :param _builtins.str search: Search merge requests against their `title` or `description`.
    :param _builtins.str sort: Return requests sorted in `asc` or `desc` order. Default is `desc`.
    :param _builtins.str source_branch: Return merge requests with the given source branch.
    :param _builtins.str state: Return all merge requests (all) or just those that are opened, closed, locked, or merged.
    :param _builtins.str target_branch: Return merge requests with the given target branch.
    :param _builtins.str updated_after: Return merge requests updated after the given time. Expected in RFC3339 format (2006-01-02T15:04:05Z).
    :param _builtins.str updated_before: Return merge requests updated before the given time. Expected in RFC3339 format (2006-01-02T15:04:05Z).
    :param _builtins.str wip: Filter merge requests against their wip status. `yes` to return only draft merge requests, `no` to return non-draft merge requests.
    """
    __args__ = dict()
    __args__['authorId'] = author_id
    __args__['authorUsername'] = author_username
    __args__['createdAfter'] = created_after
    __args__['createdBefore'] = created_before
    __args__['iids'] = iids
    __args__['milestone'] = milestone
    __args__['myReactionEmoji'] = my_reaction_emoji
    __args__['orderBy'] = order_by
    __args__['project'] = project
    __args__['reviewerUsername'] = reviewer_username
    __args__['scope'] = scope
    __args__['search'] = search
    __args__['sort'] = sort
    __args__['sourceBranch'] = source_branch
    __args__['state'] = state
    __args__['targetBranch'] = target_branch
    __args__['updatedAfter'] = updated_after
    __args__['updatedBefore'] = updated_before
    __args__['wip'] = wip
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('gitlab:index/getProjectMergeRequests:getProjectMergeRequests', __args__, opts=opts, typ=GetProjectMergeRequestsResult)
    return __ret__.apply(lambda __response__: GetProjectMergeRequestsResult(
        author_id=pulumi.get(__response__, 'author_id'),
        author_username=pulumi.get(__response__, 'author_username'),
        created_after=pulumi.get(__response__, 'created_after'),
        created_before=pulumi.get(__response__, 'created_before'),
        id=pulumi.get(__response__, 'id'),
        iids=pulumi.get(__response__, 'iids'),
        merge_requests=pulumi.get(__response__, 'merge_requests'),
        milestone=pulumi.get(__response__, 'milestone'),
        my_reaction_emoji=pulumi.get(__response__, 'my_reaction_emoji'),
        order_by=pulumi.get(__response__, 'order_by'),
        project=pulumi.get(__response__, 'project'),
        reviewer_username=pulumi.get(__response__, 'reviewer_username'),
        scope=pulumi.get(__response__, 'scope'),
        search=pulumi.get(__response__, 'search'),
        sort=pulumi.get(__response__, 'sort'),
        source_branch=pulumi.get(__response__, 'source_branch'),
        state=pulumi.get(__response__, 'state'),
        target_branch=pulumi.get(__response__, 'target_branch'),
        updated_after=pulumi.get(__response__, 'updated_after'),
        updated_before=pulumi.get(__response__, 'updated_before'),
        wip=pulumi.get(__response__, 'wip')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ProjectPagesSettingsArgs', 'ProjectPagesSettings']

@pulumi.input_type
class ProjectPagesSettingsArgs:
    def __init__(__self__, *,
                 project: pulumi.Input[_builtins.str],
                 force_https: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_unique_domain_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 keep_settings_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None):
        """
        The set of arguments for constructing a ProjectPagesSettings resource.
        :param pulumi.Input[_builtins.str] project: The project ID or path.
        :param pulumi.Input[_builtins.bool] force_https: Boolean indicating if the project is set to force https. Requires `external_https` to be configured in the GitLab instance: https://docs.gitlab.com/administration/pages/#custom-domains-with-tls-support.
        :param pulumi.Input[_builtins.bool] is_unique_domain_enabled: Boolean indicating if a unique domain is enabled.
        """
        pulumi.set(__self__, "project", project)
        if force_https is not None:
            pulumi.set(__self__, "force_https", force_https)
        if is_unique_domain_enabled is not None:
            pulumi.set(__self__, "is_unique_domain_enabled", is_unique_domain_enabled)
        if keep_settings_on_destroy is not None:
            pulumi.set(__self__, "keep_settings_on_destroy", keep_settings_on_destroy)

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Input[_builtins.str]:
        """
        The project ID or path.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter(name="forceHttps")
    def force_https(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean indicating if the project is set to force https. Requires `external_https` to be configured in the GitLab instance: https://docs.gitlab.com/administration/pages/#custom-domains-with-tls-support.
        """
        return pulumi.get(self, "force_https")

    @force_https.setter
    def force_https(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_https", value)

    @_builtins.property
    @pulumi.getter(name="isUniqueDomainEnabled")
    def is_unique_domain_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean indicating if a unique domain is enabled.
        """
        return pulumi.get(self, "is_unique_domain_enabled")

    @is_unique_domain_enabled.setter
    def is_unique_domain_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_unique_domain_enabled", value)

    @_builtins.property
    @pulumi.getter(name="keepSettingsOnDestroy")
    def keep_settings_on_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "keep_settings_on_destroy")

    @keep_settings_on_destroy.setter
    def keep_settings_on_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "keep_settings_on_destroy", value)


@pulumi.input_type
class _ProjectPagesSettingsState:
    def __init__(__self__, *,
                 deployments: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectPagesSettingsDeploymentArgs']]]] = None,
                 force_https: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_unique_domain_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 keep_settings_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ProjectPagesSettings resources.
        :param pulumi.Input[Sequence[pulumi.Input['ProjectPagesSettingsDeploymentArgs']]] deployments: List of current active deployments.
        :param pulumi.Input[_builtins.bool] force_https: Boolean indicating if the project is set to force https. Requires `external_https` to be configured in the GitLab instance: https://docs.gitlab.com/administration/pages/#custom-domains-with-tls-support.
        :param pulumi.Input[_builtins.bool] is_unique_domain_enabled: Boolean indicating if a unique domain is enabled.
        :param pulumi.Input[_builtins.str] project: The project ID or path.
        :param pulumi.Input[_builtins.str] url: The URL to access the project pages.
        """
        if deployments is not None:
            pulumi.set(__self__, "deployments", deployments)
        if force_https is not None:
            pulumi.set(__self__, "force_https", force_https)
        if is_unique_domain_enabled is not None:
            pulumi.set(__self__, "is_unique_domain_enabled", is_unique_domain_enabled)
        if keep_settings_on_destroy is not None:
            pulumi.set(__self__, "keep_settings_on_destroy", keep_settings_on_destroy)
        if project is not None:
            pulumi.set(__self__, "project", project)
        if url is not None:
            pulumi.set(__self__, "url", url)

    @_builtins.property
    @pulumi.getter
    def deployments(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ProjectPagesSettingsDeploymentArgs']]]]:
        """
        List of current active deployments.
        """
        return pulumi.get(self, "deployments")

    @deployments.setter
    def deployments(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ProjectPagesSettingsDeploymentArgs']]]]):
        pulumi.set(self, "deployments", value)

    @_builtins.property
    @pulumi.getter(name="forceHttps")
    def force_https(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean indicating if the project is set to force https. Requires `external_https` to be configured in the GitLab instance: https://docs.gitlab.com/administration/pages/#custom-domains-with-tls-support.
        """
        return pulumi.get(self, "force_https")

    @force_https.setter
    def force_https(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_https", value)

    @_builtins.property
    @pulumi.getter(name="isUniqueDomainEnabled")
    def is_unique_domain_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Boolean indicating if a unique domain is enabled.
        """
        return pulumi.get(self, "is_unique_domain_enabled")

    @is_unique_domain_enabled.setter
    def is_unique_domain_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_unique_domain_enabled", value)

    @_builtins.property
    @pulumi.getter(name="keepSettingsOnDestroy")
    def keep_settings_on_destroy(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "keep_settings_on_destroy")

    @keep_settings_on_destroy.setter
    def keep_settings_on_destroy(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "keep_settings_on_destroy", value)

    @_builtins.property
    @pulumi.getter
    def project(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The project ID or path.
        """
        return pulumi.get(self, "project")

    @project.setter
    def project(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The URL to access the project pages.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)


@pulumi.type_token("gitlab:index/projectPagesSettings:ProjectPagesSettings")
class ProjectPagesSettings(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 force_https: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_unique_domain_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 keep_settings_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        ## Example Usage

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_pages_settings`. For example:

        terraform

        import {

          to = gitlab_project_pages_settings.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        Gitlab project pages settings can be imported using the project ID, for example:

        ```sh
        $ pulumi import gitlab:index/projectPagesSettings:ProjectPagesSettings example 12345
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.bool] force_https: Boolean indicating if the project is set to force https. Requires `external_https` to be configured in the GitLab instance: https://docs.gitlab.com/administration/pages/#custom-domains-with-tls-support.
        :param pulumi.Input[_builtins.bool] is_unique_domain_enabled: Boolean indicating if a unique domain is enabled.
        :param pulumi.Input[_builtins.str] project: The project ID or path.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ProjectPagesSettingsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Example Usage

        ## Import

        Starting in Terraform v1.5.0, you can use an import block to import `gitlab_project_pages_settings`. For example:

        terraform

        import {

          to = gitlab_project_pages_settings.example

          id = "see CLI command below for ID"

        }

        Importing using the CLI is supported with the following syntax:

        Gitlab project pages settings can be imported using the project ID, for example:

        ```sh
        $ pulumi import gitlab:index/projectPagesSettings:ProjectPagesSettings example 12345
        ```

        :param str resource_name: The name of the resource.
        :param ProjectPagesSettingsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ProjectPagesSettingsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 force_https: Optional[pulumi.Input[_builtins.bool]] = None,
                 is_unique_domain_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 keep_settings_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
                 project: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ProjectPagesSettingsArgs.__new__(ProjectPagesSettingsArgs)

            __props__.__dict__["force_https"] = force_https
            __props__.__dict__["is_unique_domain_enabled"] = is_unique_domain_enabled
            __props__.__dict__["keep_settings_on_destroy"] = keep_settings_on_destroy
            if project is None and not opts.urn:
                raise TypeError("Missing required property 'project'")
            __props__.__dict__["project"] = project
            __props__.__dict__["deployments"] = None
            __props__.__dict__["url"] = None
        super(ProjectPagesSettings, __self__).__init__(
            'gitlab:index/projectPagesSettings:ProjectPagesSettings',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            deployments: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ProjectPagesSettingsDeploymentArgs', 'ProjectPagesSettingsDeploymentArgsDict']]]]] = None,
            force_https: Optional[pulumi.Input[_builtins.bool]] = None,
            is_unique_domain_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            keep_settings_on_destroy: Optional[pulumi.Input[_builtins.bool]] = None,
            project: Optional[pulumi.Input[_builtins.str]] = None,
            url: Optional[pulumi.Input[_builtins.str]] = None) -> 'ProjectPagesSettings':
        """
        Get an existing ProjectPagesSettings resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['ProjectPagesSettingsDeploymentArgs', 'ProjectPagesSettingsDeploymentArgsDict']]]] deployments: List of current active deployments.
        :param pulumi.Input[_builtins.bool] force_https: Boolean indicating if the project is set to force https. Requires `external_https` to be configured in the GitLab instance: https://docs.gitlab.com/administration/pages/#custom-domains-with-tls-support.
        :param pulumi.Input[_builtins.bool] is_unique_domain_enabled: Boolean indicating if a unique domain is enabled.
        :param pulumi.Input[_builtins.str] project: The project ID or path.
        :param pulumi.Input[_builtins.str] url: The URL to access the project pages.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ProjectPagesSettingsState.__new__(_ProjectPagesSettingsState)

        __props__.__dict__["deployments"] = deployments
        __props__.__dict__["force_https"] = force_https
        __props__.__dict__["is_unique_domain_enabled"] = is_unique_domain_enabled
        __props__.__dict__["keep_settings_on_destroy"] = keep_settings_on_destroy
        __props__.__dict__["project"] = project
        __props__.__dict__["url"] = url
        return ProjectPagesSettings(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def deployments(self) -> pulumi.Output[Sequence['outputs.ProjectPagesSettingsDeployment']]:
        """
        List of current active deployments.
        """
        return pulumi.get(self, "deployments")

    @_builtins.property
    @pulumi.getter(name="forceHttps")
    def force_https(self) -> pulumi.Output[_builtins.bool]:
        """
        Boolean indicating if the project is set to force https. Requires `external_https` to be configured in the GitLab instance: https://docs.gitlab.com/administration/pages/#custom-domains-with-tls-support.
        """
        return pulumi.get(self, "force_https")

    @_builtins.property
    @pulumi.getter(name="isUniqueDomainEnabled")
    def is_unique_domain_enabled(self) -> pulumi.Output[_builtins.bool]:
        """
        Boolean indicating if a unique domain is enabled.
        """
        return pulumi.get(self, "is_unique_domain_enabled")

    @_builtins.property
    @pulumi.getter(name="keepSettingsOnDestroy")
    def keep_settings_on_destroy(self) -> pulumi.Output[_builtins.bool]:
        return pulumi.get(self, "keep_settings_on_destroy")

    @_builtins.property
    @pulumi.getter
    def project(self) -> pulumi.Output[_builtins.str]:
        """
        The project ID or path.
        """
        return pulumi.get(self, "project")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[_builtins.str]:
        """
        The URL to access the project pages.
        """
        return pulumi.get(self, "url")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

baseUrl: Optional[str]
"""
This is the target GitLab base API endpoint. Providing a value is a requirement when working with GitLab CE or GitLab
Enterprise e.g. `https://my.gitlab.server/api/v4/`. It is optional to provide this value and it can also be sourced from
the `GITLAB_BASE_URL` environment variable. The value must end with a slash.
"""

cacertFile: Optional[str]
"""
This is a file containing the ca cert to verify the gitlab instance. This is available for use when working with GitLab
CE or Gitlab Enterprise with a locally-issued or self-signed certificate chain.
"""

clientCert: Optional[str]
"""
File path to client certificate when GitLab instance is behind company proxy. File must contain PEM encoded data.
"""

clientKey: Optional[str]
"""
File path to client key when GitLab instance is behind company proxy. File must contain PEM encoded data. Required when
`client_cert` is set.
"""

earlyAuthCheck: Optional[bool]

headers: Optional[str]
"""
A map of headers to append to all API request to the GitLab instance.
"""

insecure: Optional[bool]
"""
When set to true this disables SSL verification of the connection to the GitLab instance.
"""

retries: Optional[int]
"""
The number of retries to execute when receiving a 429 Rate Limit error. Each retry will exponentially back off.
"""

token: Optional[str]
"""
The OAuth2 Token, Project, Group, Personal Access Token or CI Job Token used to connect to GitLab. The OAuth method is
used in this provider for authentication (using Bearer authorization token). See
https://docs.gitlab.com/api/#authentication for details. It may be sourced from the `GITLAB_TOKEN` environment variable.
"""

